@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::DigitalQuill;
 BEGIN {
-  $WWW::FetchStory::Fetcher::DigitalQuill::VERSION = '0.15';
+  $WWW::FetchStory::Fetcher::DigitalQuill::VERSION = '0.16';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::DigitalQuill - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 DESCRIPTION
 
@@ -77,7 +77,7 @@ sub allow {
     my $self = shift;
     my $url = shift;
 
-    return ($url =~ /www\.digital-quill\.org/);
+    return ($url =~ /www\.digital-quill\.org$/);
 } # allow
 
 =head1 Private Methods
@@ -136,7 +136,26 @@ sub parse_toc {
     $info{characters} = $self->parse_characters(%args);
 
     $info{universe} = 'Harry Potter';
+    $info{chapters} = $self->parse_chapter_urls(%args, sid=>$sid);
 
+    return %info;
+} # parse_toc
+
+=head2 parse_chapter_urls
+
+Figure out the URLs for the chapters of this story.
+
+=cut
+sub parse_chapter_urls {
+    my $self = shift;
+    my %args = (
+	url=>'',
+	content=>'',
+	@_
+    );
+    my $content = $args{content};
+    my $sid = $args{sid};
+    my @chapters = ();
     # DigitalQuill does not have a sane chapter system
     my $fmt = 'http://www.digital-quill.org/viewstory.php?action=printable&sid=%d';
     while ($content =~ m#viewstory.php\?sid=(\d+)#sg)
@@ -146,10 +165,9 @@ sub parse_toc {
 	warn "chapter=$ch_url\n" if $self->{verbose};
 	push @chapters, $ch_url;
     }
-    $info{chapters} = \@chapters;
 
-    return %info;
-} # parse_toc
+    return \@chapters;
+} # parse_chapter_urls
 
 =head2 parse_author
 
