@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::Owl;
 BEGIN {
-  $WWW::FetchStory::Fetcher::Owl::VERSION = '0.15';
+  $WWW::FetchStory::Fetcher::Owl::VERSION = '0.16';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::Owl - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 DESCRIPTION
 
@@ -168,7 +168,6 @@ sub parse_toc {
 
     my %info = ();
     my $content = $args{content};
-    my @chapters = ();
     $info{url} = $args{url};
     my $sid='';
     if ($args{url} =~ m#psid=(\d+)#)
@@ -184,9 +183,27 @@ sub parse_toc {
     $info{author} = $self->parse_author(%args);
     $info{summary} = $self->parse_summary(%args);
     $info{characters} = $self->parse_characters(%args);
-
     $info{universe} = 'Harry Potter';
+    $info{chapters} = $self->parse_chapter_urls(%args, sid=>$sid);
 
+    return %info;
+} # parse_toc
+
+=head2 parse_chapter_urls
+
+Figure out the URLs for the chapters of this story.
+
+=cut
+sub parse_chapter_urls {
+    my $self = shift;
+    my %args = (
+	url=>'',
+	content=>'',
+	@_
+    );
+    my $content = $args{content};
+    my $sid = $args{sid};
+    my @chapters = ();
     # Owl does not have a sane chapter system
     my $fmt = 'http://owl.tauri.org/stories.php?sid=%d&action=print';
     while ($content =~ m#stories.php\?sid=(\d+)#sg)
@@ -196,10 +213,9 @@ sub parse_toc {
 	warn "chapter=$ch_url\n" if $self->{verbose};
 	push @chapters, $ch_url;
     }
-    $info{chapters} = \@chapters;
 
-    return %info;
-} # parse_toc
+    return \@chapters;
+} # parse_chapter_urls
 
 =head2 parse_title
 
